<?php

/**
 * The admin-specific functionality of the plugin.
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

class ysd_mysolution_admin {

	/**
	 * The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct($plugin_name, $version) {

		$this->plugin_name = $plugin_name;
        $this->version = $version;

        add_action('admin_menu', array($this, 'register_admin_menus'), 99999);
        add_action('admin_init', array($this, 'register_options'));
        add_action('plugin_action_links_' . YSD_MYSOLUTION_PLUGIN_BASE_FILE, array($this, 'action_links'));

        // Load scripts for use on the back-end
        add_action('admin_enqueue_scripts', array($this, 'plugin_scripts'));        

        add_filter('cron_schedules', function($schedules) {
            $schedules['ysd-mysolution-five-minutes'] = array(
                'interval' => 300,
                'display' => __('Yourstyle MySolution - 5 Minutes', YSD_MYSOLUTION_TEXT_DOMAIN)
            );
            return $schedules;
        });

        add_action('ysd_mysolution_api_sync', array($this, 'ysd_api_sync_cron_hook'));
        if (!wp_next_scheduled('ysd_mysolution_api_sync')) {
            wp_schedule_event(time(), 'ysd-mysolution-five-minutes', 'ysd_mysolution_api_sync');
        }

        /* Register custom post type */
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/admin/cpt-jobs.php';

        /* Extra functions to talk with the database */
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/admin/database.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/admin/cpt-jobs-db.php';

        /* Upgrade database if needed */
        if (YSD_MYSOLUTION_DBREVISION != get_option('ysd-msltn-db-revision')) {
            ysd_jobs_database::upgrade_db();
        }

        $ysd_mysolution_user_validation = new ysd_mysolution_user_validation();

    }
    
	/**
	 * Register the Admin Menu Pages
	 */
    public function register_admin_menus() {

        $check = ysd_mysolution_user_validation::check_validation();

        if ($check != FALSE) {
            add_submenu_page(
                'edit.php?post_type=job',
                __('Jobs - Import', YSD_MYSOLUTION_TEXT_DOMAIN),
                __('Import', YSD_MYSOLUTION_TEXT_DOMAIN),
                'manage_options',
                'job_import',
                array($this, 'page_import_jobs')
            );
        }

        if ($check != FALSE) {
            add_submenu_page(
                'edit.php?post_type=job',
                __('Jobs - Clean-up', YSD_MYSOLUTION_TEXT_DOMAIN),
                __('Clean-up', YSD_MYSOLUTION_TEXT_DOMAIN),
                'manage_options',
                'job_cleanup',
                array($this, 'page_cleanup_jobs')
            );
        }

        add_submenu_page(
            'edit.php?post_type=job',
            'Jobs - '. __('Settings'),
            __('Settings'),
            'manage_options',
            'job_settings',
            array($this, 'page_settings_jobs')
        );        

    }

    /**
     * Add action links to Plugins Page
     */
    public function action_links($links) {
        $links = array_merge(
            $links,
            array(
                '<a href="' . esc_url(admin_url( '/edit.php?post_type=job&page=job_settings')) . '">' . __('Settings') . '</a>'
            )
        );
        return $links;
    }

    /**
	 * Register options
	 */
    function register_options() {

        $settings = array(
            // Save the database revision number, used to upgrade the database and it's data if needed for a newer version of this plugin.
            'ysd-msltn-db-revision' => 'install',
            // Save the API token
            'ysd-msltn-api-token' => '0',
            // Save the API environment
            'ysd-msltn-api-environment' => '0',
            // Save the API Client ID
            'ysd-msltn-api-client-id' => '0',
            // Save the API Client Secret
            'ysd-msltn-api-client-secret' => '0',
            // Save the API Username
            'ysd-msltn-api-client-username' => 'username@mysolution.nl',
            // Save the API Password
            'ysd-msltn-api-client-password' => '0',
            // Save the Portal Base URL
            'ysd-msltn-portal-base-url' => 'https://mysolution-portal.azurewebsites.net',
            // Save the Portal Client Base URL
            'ysd-msltn-portal-base-url-client' => 'https://mysolution-portal.azurewebsites.net',
            // Save the date and time the API connection was refreshed for the last time
            'ysd-msltn-api-last-run' => 'mysolution',
            // Custom Post Type (Jobs) Archive rewrite slug
            'ysd-msltn-jobs-permalink' => 'jobs',
            // Load template from plugin
            'ysd-msltn-template-plugin' => '1',
            // Set iFrame height
            'ysd-msltn-iframe-height' => '1200',
            // Metafield CSS Class
            'ysd-msltn-meta-class' => 'job_professional_field',
            // Show or hide default metadata on archives
            'ysd-msltn-hide-metadata' => '0',
            // Customize metadata
            'ysd-msltn-custom-metadata' => '',
            // Add sidebar on archive pages
            'ysd-msltn-jobs-add-archive-sidebar' => '0',
            // Add sidebar on single pages
            'ysd-msltn-jobs-add-single-sidebar' => '2',
            // Remember list of fields that are present in the API
            'ysd-msltn-jobs-field-collector' => '',
            // If garbage collection is disabled, posts will skip the recycle bin
            'ysd-msltn-jobs-disable-garbage-collection' => '0',
            // Pause import (for example while import is already running)
            'ysd-msltn-jobs-pause-import' => '0',
            // Set default company in datafeeds
            'ysd-msltn-company' => '',
            // Enable feeds functionality
            'ysd-msltn-enable-feeds' => '0',
            // Enable the legacy version of the single template
            'ysd-msltn-legacy-single-template' => '0',
            // Set default company logo url
            'ysd-msltn-company-logo-url' => '',
            // Set salary currency
            'ysd-msltn-salary-currency' => 'EUR',
            // Set default address in feeddata
            'ysd-msltn-defaultdata-addresslocality' => '',
            // Set default street in feeddata
            'ysd-msltn-defaultdata-addressstreet' => '',
            // Set default region in feeddata
            'ysd-msltn-defaultdata-addressregion' => '',
            // Set default zipcode in feeddata
            'ysd-msltn-defaultdata-addresszipcode' => '',
            // Set default salary in feeddata
            'ysd-msltn-defaultdata-salary' => '',
            // Set default salary period in feeddata
            'ysd-msltn-defaultdata-salaryperiod' => '',
            // Set default valid through date in feeddata
            'ysd-msltn-defaultdata-validthrough' => '',
            // Enable structured data
            'ysd-msltn-structered-data' => '0',
            // Set Import Filter Field
            'ysd-msltn-api-import-filter-field' => '',
            'ysd-msltn-api-import-filter-value' => '',
            // Set CRON import offset
            'ysd-msltn-api-cron-offset-progress' => 0,
            // Show/Hide Print button
            'ysd-msltn-hide-print-button' => 0,
            // Number of posts to show in an archive
            'ysd-msltn-archive-jobs-per-page' => 15,
            
            // Field mapping settings for Professional Fields
            'ysd-msltn-jobs-field-professional_fields' => '',
            'ysd-msltn-jobs-field-professional_fields-naming' => '',
            'ysd-msltn-jobs-field-professional_fields-toggle' => '1',

            // Field mapping settings for Industry
            'ysd-msltn-jobs-field-industry' => '',
            'ysd-msltn-jobs-field-industry-naming' => '',
            'ysd-msltn-jobs-field-industry-toggle' => '1',

            // Field mapping settings for Region
            'ysd-msltn-jobs-field-region' => '',
            'ysd-msltn-jobs-field-region-naming' => '',
            'ysd-msltn-jobs-field-region-toggle' => '1',

            // Field mapping settings for Education Level
            'ysd-msltn-jobs-field-education_level' => '',
            'ysd-msltn-jobs-field-education_level-naming' => '',
            'ysd-msltn-jobs-field-education_level-toggle' => '1',

            // Field mapping settings for Employment Type
            'ysd-msltn-jobs-field-employment_type' => '',
            'ysd-msltn-jobs-field-employment_type-naming' => '',
            'ysd-msltn-jobs-field-employment_type-toggle' => '1',

            // Field mapping settings for Hours per Week
            'ysd-msltn-jobs-field-hours_per_week' => '',
            'ysd-msltn-jobs-field-hours_per_week-naming' => '',
            'ysd-msltn-jobs-field-hours_per_week-toggle' => '1',

            // Field mapping for Titles
            'ysd-msltn-jobs-field-title' => 'msf__Title__c',

            // Field mapping for Post Slug
            'ysd-msltn-jobs-field-slug' => 'title',
        );

        foreach ($settings as $key => $value) {
            register_setting('ysd-mysolution', $key);
            add_option($key, $value);
        }
    }

    // Load scripts for use on the back-end
    function plugin_scripts() {
        wp_enqueue_style('ysd_mysolution_style_admin', YSD_MYSOLUTION_PLUGIN_URL . '/assets/css/style-admin.css', false);
    }    

    public function page_settings_jobs() {
        include('views/settings_jobs.php');
    }

    public function page_import_jobs() {
        include('views/import_jobs.php');
    }

    public function page_cleanup_jobs() {
        include('views/cleanup_jobs.php');
    }

    public function ysd_api_sync_cron_hook() {
        $check = ysd_mysolution_user_validation::check_validation();
        if ($check != FALSE) {
            $ysd_jobs_db = new ysd_jobs_db;
            $ysd_jobs_db->clean_jobs(FALSE);
            $offset = get_option('ysd-msltn-api-cron-offset-progress');
            update_option('ysd-msltn-api-cron-offset-progress', $offset + 50);
            if (empty($offset)) { $offset = 0; }
            $ysd_jobs_db->import_jobs(FALSE, 50, $offset);
        }
    }

}