<?php

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

class ysd_jobs_db {

    public function import_jobs($draw_ui = FALSE, $limit = '', $offset = '') {

        $ysd_mysolution_api = new ysd_mysolution_api;
        if (!empty($limit) && (!empty($offset) || $offset === 0)) {
            $call = $ysd_mysolution_api->get_jobs($limit, $offset);
            if (empty($call)) {
                update_option('ysd-msltn-api-cron-offset-progress', '0');
            }
        } else {
            $call = $ysd_mysolution_api->get_jobs();
        }

        if ($draw_ui) {
            //echo '<pre>';
            //var_dump($call);
            //echo '</pre>';
        }

        $filter_field = get_option('ysd-msltn-api-import-filter-field');
        $filter_value = get_option('ysd-msltn-api-import-filter-value');

        $field_collector = array();

        if (isset($call['0']['errorCode'])) {

            if ($draw_ui) {
                echo '<strong>';
                _e('An error occurred while trying to retrieve the jobs from the API.');
                echo '</strong>';
                echo '<br/>';
                _e('Error Code:');
                echo ' '.$call['0']['errorCode'];
            } else {
                return FALSE;
            }

        } else {

            if ($draw_ui) {
                echo '<table class="wp-list-table widefat fixed striped">';
                echo '<thead>';
                echo '<tr>';
                echo '<td>'.__('ID', YSD_MYSOLUTION_TEXT_DOMAIN).'</td>';
                echo '<td>'.__('Title').'</td>';
                if (!empty($filter_field)) { echo '<td>'.$filter_field.'</td>'; }
                echo '<td>'.__('Deleted', YSD_MYSOLUTION_TEXT_DOMAIN).'</td>';
                echo '<td>'.__('Import Status', YSD_MYSOLUTION_TEXT_DOMAIN).'</td>';
                echo '</tr>';
                echo '</thead>';
                echo '<tbody>';
            }

            foreach ($call as $row) {
                // Extract fields from data
                foreach ($row as $key => $value) {
                    $field_collector[] = $key;
                }

                // Check if job already exists
                $q = get_posts(array(
                    'meta_key'   => 'job_api_id',
                    'meta_value' => $row['Id'],
                    'post_type' => 'job',
                    'post_status' => array('publish', 'pending', 'draft', 'future', 'private', 'trash'),
                    'posts_per_page' => 1
                ));

                if (isset($row['Sluitingsdatum__c'])) {
                    $end_date = $row['Sluitingsdatum__c'];
                } else {
                    $end_date = "";
                }
                if (!empty($end_date)) {
                    $end_date = strtotime($end_date);
                    $current_date = time();
                } else {
                    $end_date = 0;
                    $current_date = 0;
                }

                $errorcode = '200';

                // Show on website?
                $show_on_site = FALSE;
                if (isset($row['msf__Show_On_Website__c']) && $row['msf__Show_On_Website__c'] == TRUE) {
                    $show_on_site = TRUE;
                    $errorcode = '301';
                }
                if (isset($row['msf__On_Website_From__c']) && !empty($row['msf__On_Website_From__c'])) {
                    $current_date_2 = time();
                    $website_from_date = strtotime($row['msf__On_Website_From__c']);
                    if ($current_date_2 > $website_from_date) {
                        $show_on_site = TRUE;
                    } else {
                        $show_on_site = FALSE;
                        $errorcode = '302';
                    }
                    if (isset($row['msf__On_Website_To__c']) && !empty($row['msf__On_Website_To__c'])) {
                        $website_to_date = strtotime($row['msf__On_Website_To__c']);
                        if ($current_date_2 > $website_to_date) {
                            $show_on_site = FALSE;
                            $errorcode = '303';
                        }
                    }
                }

                if (!empty($q)) {
                    if (($current_date > $end_date) && (get_post_status($q[0]->ID) == 'trash')) {
                        $state = 'ok';
                    } else if ((get_post_status($q[0]->ID) == 'trash') && ($row['IsDeleted'] != TRUE) && $show_on_site != FALSE) {
                        // Pull job out of trash when needed
                        $state = 'update';
                        $this->import_job($row, $q[0]->ID);
                    } elseif (get_post_meta($q[0]->ID, 'job_last_modified', true) == $row['LastModifiedDate']) {
                        // Job in WordPress is already on the lastest version. No updated needed.
                        $state = 'ok';
                    } else {
                        // Data on API is different and the local version needs to be replaced.
                        $state = 'update';
                        $this->import_job($row, $q[0]->ID);
                    }
                } else {
                    // Job does not excist yet. Needs to be added.
                    $filter_field_check = array_search($row[$filter_field], explode(',', $filter_value), false);
                    if ($row['IsDeleted'] == TRUE) {
                        $state = 'reject';
                        $errorcode = '100';
                    } else if ($show_on_site == FALSE) {
                        $state = 'reject';
                    } else if (isset($row[$filter_field]) && (($filter_field_check == TRUE || $filter_field_check === 0))) {
                        $state = 'reject';
                        $errorcode = '400';
                    } else {
                        $state = 'import';
                        $this->import_job($row);                        
                    }
                }

                $post_title = wp_strip_all_tags($row[get_option('ysd-msltn-jobs-field-title')]);
                if (empty($post_title)) {
                    $post_title = $row['Name'];
                }

                if ($draw_ui) {
                    echo '<tr>';
                    echo '<td>'.$row['Id'].'</td>';
                    echo '<td>'.wp_strip_all_tags($post_title).'</td>';
                    if (!empty($filter_field)) {
                        if (isset($row[$filter_field])) {
                            if ($row[$filter_field] == $filter_value) {
                                echo '<td style="color: red;">'.$row[$filter_field].'</td>';
                            } else {
                                echo '<td>'.$row[$filter_field].'</td>';
                            }
                        } else {
                            echo '<td></td>';
                        }
                    }
                    echo '<td>';
                    if (empty($row['IsDeleted']) || $row['IsDeleted'] == FALSE) {
                        _e('No');
                    } else {
                        _e('Yes');
                    }
                    echo '</td>';
                    echo '<td>';
                    switch ($state) {
                        case 'import':
                            _e('Scheduled', YSD_MYSOLUTION_TEXT_DOMAIN);
                            break;

                        case 'update':
                            _e('Needs update', YSD_MYSOLUTION_TEXT_DOMAIN);
                            echo ' (<a class="" href="post.php?post='.$q[0]->ID.'&action=edit">#'.$q[0]->ID.'</a>)';
                            break;

                        case 'reject':
                            _e('Rejected', YSD_MYSOLUTION_TEXT_DOMAIN);
                            echo ' (Code: ' . $errorcode . ')';
                            break;                            
                        
                        default:
                            _e('Up-to-date', YSD_MYSOLUTION_TEXT_DOMAIN);
                            echo ' (<a class="" href="post.php?post='.$q[0]->ID.'&action=edit">#'.$q[0]->ID.'</a>)';
                            break;
                    }
                    echo '</td>';
                    echo '</tr>';
                }

            }

            sort($field_collector);
            $field_collector = array_unique($field_collector);
            if (!empty($field_collector)) {
                update_option('ysd-msltn-jobs-field-collector', serialize($field_collector));
            }

            update_option('ysd-msltn-api-last-run', time());

            if ($draw_ui) {
                echo '</tbody>';
                echo '</table>';
            } else {
                return TRUE;
            }

        }

    }

    public function import_job($data, $update_post = 0) {

        $data_prepare = $this->job_data_convert($data);
        
        $pause_import = get_option('ysd-msltn-jobs-pause-import');
        $garbage_collection = get_option('ysd-msltn-jobs-disable-garbage-collection');

        if (!empty($update_post)) {
            $data_prepare['ID'] = $update_post;
            $post_id = $data_prepare['ID'];
            if ($pause_import != '1') {
                $return = wp_update_post($data_prepare, true);
                if (function_exists('activate_search_filter')) { //refresh cache if search & filter pro is installed
                    do_action('search_filter_update_post_cache', $post_id);
                }
            }
        } else {
            if (($garbage_collection == '0' && $data_prepare['post_status'] == 'trash') || $data_prepare['post_status'] == 'publish') {
                if ($pause_import != '1' && !empty($data_prepare['meta_input']['job_Id'])) {
                    $post_id = wp_insert_post($data_prepare, true);
                    if (function_exists('activate_search_filter')) { //refresh cache if search & filter pro is installed
                        do_action('search_filter_update_post_cache', $post_id);
                    }
                    $return = $post_id;
                }
            }
        }

        if (isset($post_id)) {
            $job_professional_field = explode(';', $data_prepare['meta_input']['job_professional_field']);
            $job_professional_field = array_map('sanitize_title', $job_professional_field);
            wp_set_object_terms($post_id, $job_professional_field, 'ysdms-jobs-professional-field');

            $job_branche = explode(';', $data_prepare['meta_input']['job_branche']);
            $job_branche = array_map('sanitize_title', $job_branche);
            wp_set_object_terms($post_id, $job_branche, 'ysdms-jobs-industry');

            $job_region = explode(';', $data_prepare['meta_input']['job_work_address_city']);
            $job_region = array_map('sanitize_title', $job_region);
            wp_set_object_terms($post_id, $job_region, 'ysdms-jobs-region');

            $job_education_level = explode(';', $data_prepare['meta_input']['job_education_level']);
            $job_education_level = array_map('sanitize_title', $job_education_level);
            wp_set_object_terms($post_id, $job_education_level, 'ysdms-jobs-education_level');

            $job_employment_type = explode(';', $data_prepare['meta_input']['job_employment_type']);
            $job_employment_type = array_map('sanitize_title', $job_employment_type);
            wp_set_object_terms($post_id, $job_employment_type, 'ysdms-jobs-employment_type');

            $job_hours_per_week = explode(';', $data_prepare['meta_input']['job_hours_per_week']);
            $job_hours_per_week = array_map('sanitize_title', $job_hours_per_week);
            wp_set_object_terms($post_id, $job_hours_per_week, 'ysdms-jobs-hours-per-week');

            if (!empty($data_prepare['meta_input']['job_recruiter_name'])) {
                wp_set_object_terms($post_id, $data_prepare['meta_input']['job_recruiter_name'], 'ysdms-jobs-recruiter');
            }

            do_action('ysd_mysolution_import_job', $post_id, $data_prepare);

            return $return;
        }

    }

    // Convert the data array from the array to something that can be read by wp_insert_post()
    public function job_data_convert($job) {
        // Prepare post status
        $post_status = 'draft';
        if ($job['msf__Show_On_Website__c'] == TRUE) {
            $post_status = 'publish';
        } else if ($job['IsDeleted']) {
            $post_status = 'trash';
        }

        if (!empty(get_option('ysd-msltn-jobs-field-title')) && $job[get_option('ysd-msltn-jobs-field-title')]) {
            $post_title = wp_strip_all_tags($job[get_option('ysd-msltn-jobs-field-title')]);
            if (empty($post_title)) {
                $post_title = $job['Name'];
            }
        } else {
            $post_title = $job['Name'];
        }

        $post_title_field = '';
        $post_title_field = apply_filters('ysd-msltn-jobs-field-title', $post_title_field);
        if (!empty($post_title_field) && isset($job[$post_title_field])) {
            $post_title = $job[$post_title_field];
        }

        if (!empty($job['msf__Job_Description__c'])) {
            $content = $job['msf__Job_Description__c'];
            $content = preg_replace('#(<[a-z ]*)(style=("|\')(.*?)("|\'))([a-z ]*>)#', '\\1\\6', $content);
        } else {
            $content = '';
        }

        // Set Post Slug
        if (get_option('ysd-msltn-jobs-field-slug') == 'id') {
            $post_slug = $job['Id'];
        } else {
            $post_slug = sanitize_title($post_title);
        }

        $post_slug_field = '';
        $post_slug_field = apply_filters('ysd-msltn-jobs-field-slug', $post_slug_field);
        if (!empty($post_slug_field) && isset($job[$post_slug_field])) {
            $post_slug = $job[$post_slug_field];
        }

        // Prepare the data
        $post_data = array(
            'post_date'     => $job['CreatedDate'],
            'post_content'  => $content,
            'post_title'    => wp_strip_all_tags($post_title, true),
            'post_status'   => $post_status,
            'post_type'     => 'job',
            'comment_status'=> 'closed',
            'ping_status'   => 'closed',
            'post_name'     => $post_slug,
            'post_modified' => $job['LastModifiedDate'],
            'meta_input'    => array(
                'job_api_id'         => $job['Id'],
                'job_last_modified'  => $job['LastModifiedDate'],
            ),
        );

        /* Import custom fields */
        $fields = get_option('ysd-msltn-jobs-field-collector');
        $fields = unserialize($fields);
        if (!is_array($fields)) {
            $fields = array();
        }
        foreach($fields as $f) {
            if (isset($job[$f])) {
                if (is_array($job[$f])) {
                    $post_data['meta_input']['job_'.$f] = serialize($job[$f]);
                } else {
                    $post_data['meta_input']['job_'.$f] = $job[$f];
                    $post_data['meta_input']['job_'.$f] = preg_replace('#(<[a-z ]*)(style=("|\')(.*?)("|\'))([a-z ]*>)#', '\\1\\6', $post_data['meta_input']['job_'.$f]);
                }
            }
        }

        // Get recruiter name
        $post_data['meta_input']['job_recruiter_name']      = (isset($job['msf__Recruiter__r']['Name']))? $job['msf__Recruiter__r']['Name'] : "";

        // Field Mapping
        $post_data['meta_input']['job_professional_field']  = (isset($job['msf__Professional_Field__c']))? $job['msf__Professional_Field__c'] : "";
        $post_data['meta_input']['job_branche']             = (isset($job['Branche__c']))? $job['Branche__c'] : ""; //This is always a custom field.
        $post_data['meta_input']['job_work_address_city']   = (isset($job['msf__Work_Address_City__c']))? $job['msf__Work_Address_City__c'] : "";
        $post_data['meta_input']['job_education_level']     = (isset($job['msf__Education_Level__c']))? $job['msf__Education_Level__c'] : "";
        $post_data['meta_input']['job_employment_type']     = (isset($job['msf__Employment_Type__c']))? $job['msf__Employment_Type__c'] : "";
        $post_data['meta_input']['job_hours_per_week']      = (isset($job['msf__Hours_Per_Week__c']))? $job['msf__Hours_Per_Week__c'] : "";

        if (!empty(get_option('ysd-msltn-jobs-field-professional_fields') && !empty($job[get_option('ysd-msltn-jobs-field-professional_fields')]))) {
            $post_data['meta_input']['job_professional_field']  = $job[get_option('ysd-msltn-jobs-field-professional_fields')];
        }
        if (!empty(get_option('ysd-msltn-jobs-field-industry') && !empty($job[get_option('ysd-msltn-jobs-field-industry')]))) {
            $post_data['meta_input']['job_branche']  = $job[get_option('ysd-msltn-jobs-field-industry')];
        }
        if (!empty(get_option('ysd-msltn-jobs-field-region') && !empty($job[get_option('ysd-msltn-jobs-field-region')]))) {
            $post_data['meta_input']['job_work_address_city']  = $job[get_option('ysd-msltn-jobs-field-region')];
        }
        if (!empty(get_option('ysd-msltn-jobs-field-education_level') && !empty($job[get_option('ysd-msltn-jobs-field-education_level')]))) {
            $post_data['meta_input']['job_education_level']  = $job[get_option('ysd-msltn-jobs-field-education_level')];
        }
        if (!empty(get_option('ysd-msltn-jobs-field-employment_type') && !empty($job[get_option('ysd-msltn-jobs-field-employment_type')]))) {
            $post_data['meta_input']['job_employment_type']  = $job[get_option('ysd-msltn-jobs-field-employment_type')];
        }
        if (!empty(get_option('ysd-msltn-jobs-field-hours_per_week') && !empty($job[get_option('ysd-msltn-jobs-field-hours_per_week')]))) {
            $post_data['meta_input']['job_hours_per_week']  = $job[get_option('ysd-msltn-jobs-field-hours_per_week')];
        }

        if (get_option('ysd-msltn-jobs-field-education_level-toggle') != 1) {
            $job_education_level = explode(';', $post_data['meta_input']['job_education_level']);
            foreach ($job_education_level as $x) {
                wp_insert_term($x, 'ysdms-jobs-education_level');
            }
        }

        if (get_option('ysd-msltn-jobs-field-employment_type-toggle') != 1) {
            $job_employment_type = explode(';', $post_data['meta_input']['job_employment_type']);
            foreach ($job_employment_type as $x) {
                wp_insert_term($x, 'ysdms-jobs-employment_type');
            }
        }

        if (get_option('ysd-msltn-jobs-field-industry-toggle') != 1) {
            $job_branche = explode(';', $post_data['meta_input']['job_branche']);
            foreach ($job_branche as $x) {
                wp_insert_term($x, 'ysdms-jobs-industry');
            }
        }

        if (get_option('ysd-msltn-jobs-field-professional_fields-toggle') != 1) {
            $job_professional_field = explode(';', $post_data['meta_input']['job_professional_field']);
            foreach ($job_professional_field as $x) {
                wp_insert_term($x, 'ysdms-jobs-professional-field');
            }
        }

        if (get_option('ysd-msltn-jobs-field-region-toggle') != 1) {
            $job_region = explode(';', $post_data['meta_input']['job_work_address_city']);
            foreach ($job_region as $x) {
                wp_insert_term($x, 'ysdms-jobs-region');
            }
        }

        if (get_option('ysd-msltn-jobs-field-hours_per_week-toggle') != 1) {
            $job_hours_per_week = explode(';', $post_data['meta_input']['job_hours_per_week']);
            foreach ($job_hours_per_week as $x) {
                wp_insert_term($x, 'ysdms-jobs-hours-per-week');
            }
        }

        if (isset($job['msf__Recruiter__r']) && is_array($job['msf__Recruiter__r']) && isset($job['msf__Recruiter__r']['Name'])) {
            wp_insert_term($job['msf__Recruiter__r']['Name'], 'ysdms-jobs-recruiter');
        }

        //Add other important fields to the content, so we can make them searchable.
        if (isset($post_data['meta_input']['job_msf__Job_Requirements__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Job_Requirements__c'];
        }
        if (isset($post_data['meta_input']['job_msf__Employment_Conditions__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Employment_Conditions__c'];
        }
        if (isset($post_data['meta_input']['job_msf__Company_Description__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Company_Description__c'];
        }
        if (isset($post_data['meta_input']['job_msf__Application_Procedure__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Application_Procedure__c'];
        }
        if (isset($post_data['meta_input']['job_Id'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_Id'];
        }
        if (isset($post_data['meta_input']['job_msf__Professional_Field__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Professional_Field__c'];
        }
        if (isset($post_data['meta_input']['job_DPS_Branche__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_DPS_Branche__c'];
        }
        if (isset($post_data['meta_input']['job_msf__Work_Address_City__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Work_Address_City__c'];
        }
        if (isset($post_data['meta_input']['job_msf__Education_Level__c'])) {
            $post_data['post_content'].= '<br/>' . $post_data['meta_input']['job_msf__Education_Level__c'];
        }

        return $post_data;
    }

    /**
     * Loop through jobs and trash the ones that are not present on the API environment.
     */
    function clean_jobs($draw_ui = TRUE) {

        $ysd_mysolution_api = new ysd_mysolution_api;

        $filter_field = get_option('ysd-msltn-api-import-filter-field');
        $filter_value = get_option('ysd-msltn-api-import-filter-value');        

        $jobs = get_posts(array(
            'posts_per_page'    => -1,
            'post_type'         => 'job',
            'post_status'       => array('publish', 'pending', 'draft', 'future', 'private', 'trash'),
            'order_by'          => 'title',
        ));

        $call = $ysd_mysolution_api->get_jobs();

        //Some variables we need later on in the process
        $trash_jobs = array();
        $keep_jobs  = array();

        if (isset($call['0']['errorCode'])) {

            if ($draw_ui) {
                echo '<strong>';
                _e('An error occurred while trying to retrieve the jobs from the API.');
                echo '</strong>';
                echo '<br/>';
                _e('Error Code:');
                echo ' '.$call['0']['errorCode'];
            } else {
                return FALSE;
            }

        } else {

            // Check if a job is deleted on the API and sort it in the right array.
            foreach ($call as $crow) {
                if ($crow['IsDeleted'] == TRUE) {
                    $trash_jobs[] = $crow['Id'];
                } else {
                    $keep_jobs[] = $crow['Id'];
                }
            }

            if ($draw_ui) {
                echo '<table class="wp-list-table widefat fixed striped">';
                echo '<thead>';
                echo '<tr>';
                echo '<td>'.__('ID', YSD_MYSOLUTION_TEXT_DOMAIN).'</td>';
                echo '<td>'.__('Title').'</td>';
                if (!empty($filter_field)) { echo '<td>'.$filter_field.'</td>'; }
                echo '<td>'.__('Move to trash?', YSD_MYSOLUTION_TEXT_DOMAIN).'</td>';
                echo '</tr>';
                echo '</thead>';
                echo '<tbody>';
            }

            foreach ($jobs as $row) {
                $job_api_id = get_post_meta($row->ID, 'job_api_id', true);
                if (!empty($job_api_id)) {
                    $trash = FALSE;
                    if (array_search($job_api_id, $trash_jobs) == TRUE) {
                        $trash = TRUE;
                    } else if (array_search($job_api_id, $keep_jobs) === FALSE) {
                        $trash = TRUE;
                    }

                    // Check if end date expired
                    $end_date = get_post_meta($row->ID, 'job_Sluitingsdatum__c', true);
                    if (!empty($end_date)) {
                        $end_date = strtotime($end_date);
                        $current_date = time();
                        if ($current_date > $end_date) {
                            $trash = TRUE;
                        }
                    }
                    
                    $site_end_date = get_post_meta($row->ID, 'job_msf__On_Website_To__c', true);
                    if (!empty($site_end_date)) {
                        $site_end_date = strtotime($site_end_date);
                        $current_date = time();
                        if ($current_date > $site_end_date) {
                            $trash = TRUE;
                        }
                    }

                    if (!empty($filter_field)) {
                        if (!empty(get_post_meta($row->ID, 'job_'.$filter_field, true))) {
                            $filter_field_check = array_search(get_post_meta($row->ID, 'job_'.$filter_field, true), explode(',', $filter_value), false);
                            if ($filter_field_check == TRUE || $filter_field_check === 0) {
                                $trash = TRUE;
                            }
                        }
                    }

                    $show_on_site = get_post_meta($row->ID, 'job_msf__Show_On_Website__c', true);
                    if (empty($show_on_site) || $show_on_site == FALSE) {
                        $trash = TRUE;
                    }                    

                    if ($trash == TRUE) {
                        $this->trash_job($row->ID);
                    }

                    if ($draw_ui) {
                        echo '<tr>';
                        echo '<td>'.get_post_meta($row->ID, 'job_api_id', true).'</td>';
                        echo '<td>'.$row->post_title.'</td>';
                        if (!empty($filter_field)) {
                            if (!empty(get_post_meta($row->ID, 'job_'.$filter_field, true))) {
                                if (get_post_meta($row->ID, 'job_'.$filter_field, true) == $filter_value) {
                                    echo '<td style="color: red;">'.get_post_meta($row->ID, 'job_'.$filter_field, true).'</td>';
                                } else {
                                    echo '<td>'.get_post_meta($row->ID, 'job_'.$filter_field, true).'</td>';
                                }
                            } else {
                                echo '<td></td>';
                            }
                        }                        
                        echo '<td>';
                        if ($trash == TRUE) {
                            _e('Yes');
                        } else {
                            _e('No');
                        }
                        echo '</td>';
                        echo '</tr>';
                    }
                }
            }

            if ($draw_ui) {
                echo '</tbody>';
                echo '</table>';
            } else {
                return TRUE;
            }

        }

    }

    /**
     * Put a single job in the trash by post_id
     */
    function trash_job($id) {

        $garbage_collection = get_option('ysd-msltn-jobs-disable-garbage-collection');
        if ($garbage_collection == '0') {
            wp_update_post(array(
                'ID'            => $id,
                'post_status'   => 'trash'
            ));        
        } else {
            wp_delete_post($id, true);
        }

    }

    /**
     * Trash all jobs
     */
    function trash_all_jobs() {

        update_option('ysd-msltn-jobs-pause-import', '1');

        $args = array(
            'posts_per_page' => -1,
            'post_type' => 'job',
            'post_status' => array('publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', 'trash'),
        );
        $query = new WP_Query($args);

        if ($query->have_posts()) {
            $i = 0;
            while ($query->have_posts()) {
                $query->the_post();
                if ($i > 0) {
                    wp_delete_post($query->post->ID, true);
                }
                $i++;
            }
            wp_reset_postdata();
            update_option('ysd-msltn-jobs-pause-import', '0');
            return $i;
        } else {
            update_option('ysd-msltn-jobs-pause-import', '0');
            return 0;
        }

    }

}