<?php

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

class ysd_mysolution_cpt_jobs {

    public function __construct() {
        // Register Custom Post Type
        add_action('init', array($this, 'cpt_jobs'), 0);
        
        // Register Meta Box Field List
        add_action('add_meta_boxes', array($this, 'cpt_jobs_meta_box'));
        
        // Register all Taxonomies
        add_action('init', array($this, 'cpt_jobs_register_taxonomies'), 0);

        // Recruiter Fields
        add_action('ysdms-jobs-recruiter_edit_form_fields', array($this, 'taxonomy_recruiter_custom_fields_render'), 10, 2);
        add_action('ysdms-jobs-recruiter_add_form_fields', array($this, 'taxonomy_recruiter_custom_fields_add_render'), 10, 1);
        add_action('created_ysdms-jobs-recruiter', array($this, 'taxonomy_recruiter_custom_fields_save'));
        add_action('edited_ysdms-jobs-recruiter', array($this, 'taxonomy_recruiter_custom_fields_save'));
    }

    // Register Custom Post Type
    public function cpt_jobs() {
        $rewrite = array(
            'slug'      => get_option('ysd-msltn-jobs-permalink'),
            'with_front'=> true,
            'pages'     => true,
            'feeds'     => false,
        );

        $args = array(
            'supports'              => array('title'),
            'hierarchical'          => false,
            'public'                => true,
            'show_ui'               => true,
            'show_in_menu'          => true,
            'menu_position'         => 20,
            'menu_icon'             => 'dashicons-text-page',
            'show_in_admin_bar'     => true,
            'show_in_nav_menus'     => true,
            'can_export'            => true,
            'has_archive'           => true,
            'exclude_from_search'   => false,
            'publicly_queryable'    => true,
            'capability_type'       => 'page',
            'show_in_rest'          => false,
            'rewrite'               => $rewrite,
        );
        bwhf_register_post_type('job', $args, __('Job', YSD_MYSOLUTION_TEXT_DOMAIN), __('Jobs', YSD_MYSOLUTION_TEXT_DOMAIN), YSD_MYSOLUTION_TEXT_DOMAIN);
    }

    // Register Meta Box for Field List
    function cpt_jobs_meta_box() {
        add_meta_box('ysd_cpt_jobs_meta_box', __('Fields', YSD_MYSOLUTION_TEXT_DOMAIN), array($this, 'cpt_jobs_meta_box_html'), 'job', 'normal', 'default');
    }

    // Render Meta Box Field List
    function cpt_jobs_meta_box_html($post) {
        wp_nonce_field('_ysd_cpt_jobs_meta_box_nonce', 'ysd_cpt_jobs_meta_box_nonce'); ?>

        <style>
            .cptjobs-fieldtable th {
                vertical-align: top;
                text-align: left;
                border-bottom: 1px solid #eee;
            }
            .cptjobs-fieldtable td {
                border-bottom: 1px solid #eee;
            }
            .cptjobs-fieldtable tr:last-child td, .cptjobs-fieldtable tr:last-child th {
                border-bottom: 0px solid #eee;
            }
        </style>

        <table class="cptjobs-fieldtable">
            <?php
                $fields = get_option('ysd-msltn-jobs-field-collector');
                $fields = unserialize($fields);
                if (!is_array($fields)) {
                    $fields = array();
                }
                foreach ($fields as $f) {
                    echo '<tr>';
                    echo '<th><label for="job_'.$f.'">job_'.$f.'</label></th>';
                    echo '<td>'.get_post_meta($post->ID, 'job_'.$f, true).'</td>';
                    echo '</tr>';
                }
            ?>
        </table>
        
        <?php
    }

    // Register all Taxonomies
    function cpt_jobs_register_taxonomies() {

        $args = array(
            'hierarchical'               => false,
            'public'                     => true,
            'show_ui'                    => true,
            'show_admin_column'          => true,
            'show_in_nav_menus'          => false,
            'show_tagcloud'              => false,
        );

        // Professional Fields
        if (get_option('ysd-msltn-jobs-field-professional_fields-toggle') != 1) {
            $label_plural = __('Professional Fields', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Professional Field', YSD_MYSOLUTION_TEXT_DOMAIN);
            
            $naming = get_option('ysd-msltn-jobs-field-professional_fields-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-professional-field', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Industry
        if (get_option('ysd-msltn-jobs-field-industry-toggle') != 1) {
            $label_plural = __('Industries', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Industry', YSD_MYSOLUTION_TEXT_DOMAIN);
            
            $naming = get_option('ysd-msltn-jobs-field-industry-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-industry', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Region
        if (get_option('ysd-msltn-jobs-field-region-toggle') != 1) {
            $label_plural = __('Regions', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Region', YSD_MYSOLUTION_TEXT_DOMAIN);
            
            $naming = get_option('ysd-msltn-jobs-field-region-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-region', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Education Level
        if (get_option('ysd-msltn-jobs-field-education_level-toggle') != 1) {
            $label_plural = __('Education Levels', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Education Level', YSD_MYSOLUTION_TEXT_DOMAIN);
            
            $naming = get_option('ysd-msltn-jobs-field-education_level-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-education_level', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Employment Type
        if (get_option('ysd-msltn-jobs-field-employment_type-toggle') != 1) {
            $label_plural = __('Employment Types', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Employment Type', YSD_MYSOLUTION_TEXT_DOMAIN);
            
            $naming = get_option('ysd-msltn-jobs-field-employment_type-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-employment_type', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Hours Per Week
        if (get_option('ysd-msltn-jobs-field-hours_per_week-toggle') != 1) {
            $label_plural = __('Hours Per Week', YSD_MYSOLUTION_TEXT_DOMAIN);
            $label_single = __('Hour Per Week', YSD_MYSOLUTION_TEXT_DOMAIN);

            $naming = get_option('ysd-msltn-jobs-field-hours_per_week-naming');
            if (!empty($naming)) {
                $label_plural = $naming;
                $label_single = $naming;
            }

            bwhf_register_taxonomy('ysdms-jobs-hours-per-week', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);
        }

        // Recruiter
        $label_plural = __('Recruiters', YSD_MYSOLUTION_TEXT_DOMAIN);
        $label_single = __('Recruiter', YSD_MYSOLUTION_TEXT_DOMAIN);

        bwhf_register_taxonomy('ysdms-jobs-recruiter', array('job'), $args, $label_single, $label_plural, YSD_MYSOLUTION_TEXT_DOMAIN);

    }

    // Fields recruiter taxonomy
    function taxonomy_recruiter_custom_fields() {
        $fields = array(
            'ysdms-recruiter-phone' => array(
                'id'        => 'ysdms-recruiter-phone',
                'label'     => __('Phonenumber', YSD_MYSOLUTION_TEXT_DOMAIN),
                'type'      => 'text',
                'value'     => '',
                'default'   => '',                
            ),
            'ysdms-recruiter-mail' => array(
                'id'        => 'ysdms-recruiter-mail',
                'label'     => __('Email Address', YSD_MYSOLUTION_TEXT_DOMAIN),
                'type'      => 'text',
                'value'     => '',
                'default'   => '',                
            ),
            'ysdms-recruiter-img' => array(
                'id'        => 'ysdms-recruiter-img',
                'label'     => __('Image (URL)', YSD_MYSOLUTION_TEXT_DOMAIN),
                'type'      => 'media',
                'value'     => '',
                'default'   => '',
            ),
        );
        return $fields;
    }

    function taxonomy_recruiter_custom_fields_render($term, $taxonomy) {
        $fields = $this->taxonomy_recruiter_custom_fields();
        
        $fields['ysdms-recruiter-phone']['value'] = get_term_meta($term->term_id, 'ysdms-recruiter-phone', true);
        $fields['ysdms-recruiter-mail']['value'] = get_term_meta($term->term_id, 'ysdms-recruiter-mail', true);
        $fields['ysdms-recruiter-img']['value'] = get_term_meta($term->term_id, 'ysdms-recruiter-img', true);

        echo bwhf_render_fields($fields, 'taxonomy_edit', YSD_MYSOLUTION_TEXT_DOMAIN);
    }

    function taxonomy_recruiter_custom_fields_add_render($taxonomy) {
        $fields = $this->taxonomy_recruiter_custom_fields();

        echo bwhf_render_fields($fields, 'taxonomy_add', YSD_MYSOLUTION_TEXT_DOMAIN);
    }

    function taxonomy_recruiter_custom_fields_save($term_id) {
        $fields = $this->taxonomy_recruiter_custom_fields();

        foreach ($fields as $f) {
            if (isset($f['id']) && isset($_POST[$f['id']])) {
                update_term_meta($term_id, $f['id'], sanitize_text_field($_POST[$f['id']]));
            }
        }
    }

    // Fields for mapped taxonomies
    static function mapped_taxonomy_custom_fields() {
        $fields = array(
            'ysdms-ctx-img' => array(
                'id'        => 'ysdms-ctx-img',
                'label'     => __('Image (URL)', YSD_MYSOLUTION_TEXT_DOMAIN),
                'type'      => 'media',
                'value'     => '',
                'default'   => '',
            ),
        );
        return $fields;
    }

}

$ysd_mysolution_cpt_jobs = new ysd_mysolution_cpt_jobs;

function ysdm_ctx_media_upload_field($term, $taxonomy) {
    $fields = ysd_mysolution_cpt_jobs::mapped_taxonomy_custom_fields();
    if (isset($fields['ysdms-ctx-img'])) {
        $fields['ysdms-ctx-img']['value'] = get_term_meta($term->term_id, 'ysdms-ctx-img', true);
    }
    
    echo bwhf_render_fields($fields, 'taxonomy_edit', YSD_MYSOLUTION_TEXT_DOMAIN);
}

function ysdm_ctx_media_upload_field_save($term_id) {
    $fields = ysd_mysolution_cpt_jobs::mapped_taxonomy_custom_fields();
    foreach ($fields as $f) {
        if (isset($f['id']) && isset($_POST[$f['id']])) {
            update_term_meta($term_id, $f['id'], sanitize_text_field($_POST[$f['id']]));
        }
    }
}

if (get_option('ysd-msltn-jobs-field-professional-field-toggle') != 1) {
    add_action('ysdms-jobs-professional-field_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-professional-field', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-professional-field', 'ysdm_ctx_media_upload_field_save');
}
if (get_option('ysd-msltn-industry-field-toggle') != 1) {
    add_action('ysdms-jobs-industry_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-industry', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-industry', 'ysdm_ctx_media_upload_field_save');
}
if (get_option('ysd-msltn-region-toggle') != 1) {
    add_action('ysdms-jobs-region_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-region', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-region', 'ysdm_ctx_media_upload_field_save');
}
if (get_option('ysd-msltn-education_level-toggle') != 1) {
    add_action('ysdms-jobs-education_level_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-education_level', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-education_level', 'ysdm_ctx_media_upload_field_save');
}
if (get_option('ysd-msltn-employment_type-toggle') != 1) {
    add_action('ysdms-jobs-employment_type_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-employment_type', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-employment_type', 'ysdm_ctx_media_upload_field_save');
}
if (get_option('ysd-msltn-hours-per-week-toggle') != 1) {
    add_action('ysdms-jobs-hours-per-week_edit_form_fields', 'ysdm_ctx_media_upload_field', 10, 2);
    add_action('created_ysdms-jobs-hours-per-week', 'ysdm_ctx_media_upload_field_save');
    add_action('edited_ysdms-jobs-hours-per-week', 'ysdm_ctx_media_upload_field_save');
}