<?php

/**
 * API Class to communicate with the Mysolution API
 * API Documentation can be found here: https://swagger.mysolution.nl/
 * 
 * Current code is based on API version 1.3.0
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

class ysd_mysolution_api {

    /**
     * The Base URL to access the API
     */
    protected $api_base_url;

    /**
     * The token needed to accesss the API
     */
    protected $api_token;

    /**
     * Define class variables
     */
    public function __construct() {
        $environment = get_option('ysd-msltn-api-environment');
        if (!empty($environment)) {
            $this->api_base_url = "https://$environment.my.salesforce.com/services/";
        } else {
            $this->api_base_url = "https://mysolution.my.salesforce.com/services/";
        }

        $this->api_token = get_option('ysd-msltn-api-token');
    }

    /**
     * The main function that handles the api connection on all GET calls.
     */
    public function api($endpoint, $method = "GET", $data = array(), $auth = 0) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $this->api_base_url . $endpoint);
        curl_setopt($ch, CURLOPT_HEADER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        
        curl_setopt($ch, CURLOPT_ENCODING, '');
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);

        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);

        curl_setopt($ch, CURLOPT_TIMEOUT, 60);

        if (!empty($method)) {
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
        }

        if ($auth === 1) {
            $client_id = stripslashes(get_option('ysd-msltn-api-client-id'));
            $client_secret = stripslashes(get_option('ysd-msltn-api-client-secret'));
            $username = get_option('ysd-msltn-api-client-username');
            $password = stripslashes(get_option('ysd-msltn-api-client-password'));

            if (!empty($client_id) && !empty($client_secret) && !empty($username) && !empty($password)) {
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query(array(
                    'grant_type'    => 'password',
                    'client_id'     => $client_id,
                    'client_secret' => $client_secret,
                    'username'      => $username,
                    'password'      => $password
                )));
            }
        } else if (!empty($data) && is_array($data)) {
            // nothing yet. maybe later
        }
        
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Authorization: Bearer ' . $this->api_token
        ));

        curl_setopt($ch, CURLOPT_USERAGENT, 'Yourstyle MySolution - Wordpress Plugin');

        $result = curl_exec($ch);

        $result = json_decode($result, true);

        if (isset($result['0']['errorCode'])) {
            if ($result['0']['errorCode'] == "INVALID_SESSION_ID") {
                $this->refresh_token();
            }
        }

        return $result;
    }

    public function refresh_token() {
        $endpoint = 'oauth2/token';
        $result = $this->api($endpoint, 'POST', array(), 1);
        if (!empty($result['access_token'])) {
            update_option('ysd-msltn-api-token', $result['access_token']);
            return TRUE;
        } else {
            return FALSE;
        }
    }

    public function get_jobs($limit = '', $offset = '') {
        $check = ysd_mysolution_user_validation::check_validation();
        if ($check != FALSE) {
            if (!empty($limit) && (!empty($offset) || $offset === 0)) {
                $endpoint = 'apexrest/msf/api/job/get?limit='.$limit.'&offset='.$offset;
            } else {
                $endpoint = 'apexrest/msf/api/job/get';
            }
            return $this->api($endpoint);
        } else {
            return FALSE;
        }
    }

}