<?php

/**
 * Register Post Type 
 * 
 * This version of the register_post_type() function automaticly generates the labels based on the single and plural string
 * 
 * $post_type (string) (required) Post type key.
 * $args (array|string) (optional) Array or string of arguments for registering a post type.
 * $post_type_name_single (string) (optional)
 * $post_type_name_plural (string) (optional)
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

if (!function_exists('bwhf_register_post_type')) {
    function bwhf_register_post_type($post_type, $args = '', $post_type_name_single = '', $post_type_name_plural = '', $textdomain = 'bwhf') {

        if (!empty($post_type_name_single) && !empty($post_type_name_plural)) {
            $labels = array(
                'name'                  => _x($post_type_name_plural, 'Post Type General Name', $textdomain),
                'singular_name'         => _x($post_type_name_single, 'Post Type Singular Name', $textdomain),
                'menu_name'             => __($post_type_name_plural, $textdomain),
                'name_admin_bar'        => __($post_type_name_single, $textdomain),
                'archives'              => sprintf(__('%s Archives', $textdomain), $post_type_name_single),
                'attributes'            => sprintf(__('%s Attributes', $textdomain), $post_type_name_single),
                'parent_item_colon'     => sprintf(__('Parent %s:', $textdomain), $post_type_name_single),
                'all_items'             => sprintf(__('All %s', $textdomain), $post_type_name_plural),
                'add_new_item'          => sprintf(__('Add New %s', $textdomain), $post_type_name_single),
                //'add_new'               => __('Add New', $textdomain),
                'new_item'              => sprintf(__('New %s', $textdomain), $post_type_name_single),
                'edit_item'             => sprintf(__('Edit %s', $textdomain), $post_type_name_single),
                'update_item'           => sprintf(__('Update %s', $textdomain), $post_type_name_single),
                'view_item'             => sprintf(__('View %s', $textdomain), $post_type_name_single),
                'view_items'            => sprintf(__('View %s', $textdomain), $post_type_name_plural),
                'search_items'          => sprintf(__('Search %s', $textdomain), $post_type_name_single),
                //'not_found'             => __('Not found', $textdomain),
                //'not_found_in_trash'    => __('Not found in Trash', $textdomain),
                //'featured_image'        => __('Featured Image', $textdomain),
                //'set_featured_image'    => __('Set featured image', $textdomain),
                //'remove_featured_image' => __('Remove featured image', $textdomain),
                //'use_featured_image'    => __('Use as featured image', $textdomain),
                'insert_into_item'      => sprintf(__('Insert into %s', $textdomain), $post_type_name_single),
                'uploaded_to_this_item' => sprintf(__('Uploaded to this %s', $textdomain), $post_type_name_single),
                'items_list'            => sprintf(__('%s list', $textdomain), $post_type_name_plural),
                'items_list_navigation' => sprintf(__('%s list navigation', $textdomain), $post_type_name_plural),
                'filter_items_list'     => sprintf(__('Filter %s list', $textdomain), $post_type_name_plural),
            );

            if (!isset($args['labels'])) {
                $args['label'] = $post_type_name_plural;
                $args['labels'] = $labels;
            }        
        }

        register_post_type($post_type, $args);

    }
}