<?php

/**
 * Register Taxonomy
 * 
 * This version of the register_post_type() function automaticly generates the labels based on the single and plural string
 * 
 * $taxonomy (string) (required) Taxonomy key, must not exceed 32 characters.
 * $object_type (string) (required) Object type or array of object types with which the taxonomy should be associated.
 * $args (array|string) (optional) Array or string of arguments for registering a taxonomy.
 * $taxonomy_name_single (string) (optional)
 * $taxonomy_name_plural (string) (optional)
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

if (!function_exists('bwhf_register_taxonomy')) {
    function bwhf_register_taxonomy($taxonomy, $object_type, $args = '', $taxonomy_name_single = '', $taxonomy_name_plural = '', $textdomain = 'bwhf') {

        if (!empty($taxonomy_name_single) && !empty($taxonomy_name_plural)) {
            $labels = array(
                'name'                       => _x($taxonomy_name_plural, 'Taxonomy General Name', $textdomain),
                'singular_name'              => _x($taxonomy_name_single, 'Taxonomy Singular Name', $textdomain),
                'menu_name'                  => __($taxonomy_name_plural, $textdomain),
                'all_items'                  => sprintf(__('All %s', $textdomain), $taxonomy_name_plural),
                'parent_item'                => sprintf(__('Parent %s', $textdomain), $taxonomy_name_single),
                'parent_item_colon'          => sprintf(__('Parent %s:', $textdomain), $taxonomy_name_single),
                'new_item_name'              => sprintf(__('New %s Name', $textdomain), $taxonomy_name_single),
                'add_new_item'               => sprintf(__('Add New %s', $textdomain), $taxonomy_name_single),
                'edit_item'                  => sprintf(__('Edit %s', $textdomain), $taxonomy_name_single),
                'update_item'                => sprintf(__('Update %s', $textdomain), $taxonomy_name_single),
                'view_item'                  => sprintf(__('View %s', $textdomain), $taxonomy_name_single),
                'separate_items_with_commas' => sprintf(__('Separate %s with commas', $textdomain), $taxonomy_name_plural),
                'add_or_remove_items'        => sprintf(__('Add or remove %s', $textdomain), $taxonomy_name_plural),
                //'choose_from_most_used'      => __('Choose from the most used', $textdomain),
                'popular_items'              => sprintf(__('Popular %s', $textdomain), $taxonomy_name_plural),
                'search_items'               => sprintf(__('Search %s', $textdomain), $taxonomy_name_plural),
                //'not_found'                  => __('Not Found', $textdomain),
                'no_terms'                   => sprintf(__('No %s', $textdomain), $taxonomy_name_plural),
                'items_list'                 => sprintf(__('%s list', $textdomain), $taxonomy_name_plural),
                'items_list_navigation'      => sprintf(__('%s list navigation', $textdomain), $taxonomy_name_plural),
            );

            if (!isset($args['labels'])) {
                $args['labels'] = $labels;
            }
        }

        register_taxonomy($taxonomy, $object_type, $args);

    }
}