<?php

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

function ysd_mysolution_salary_string($post_id, $enable_translations = true, $only_price = false) {
    $salary_period_str = ysd_mysolution_salary_period_string($post_id, $enable_translations);

    $salary_from   = get_post_meta($post_id, 'job_msf__Salary_from__c', true);
    $salary_to     = get_post_meta($post_id, 'job_msf__Salary_to__c', true);
    if (!empty($salary_from) && !empty($salary_to)) {
        $salary_str = ysd_mysolution_price_format($salary_from) . ' - ' . ysd_mysolution_price_format($salary_to);
        if ($only_price == false) {
            $salary_str.= ' ' . $salary_period_str;
        }
    } elseif (!empty($salary_from)) {
        $salary_str = ysd_mysolution_price_format($salary_from);
        if ($only_price == false) {
            $salary_str.= ' ' . $salary_period_str;
        }
    } else {
        $salary_str = '';
    }

    return $salary_str;
}

function ysd_mysolution_salary_period_string($post_id, $enable_translations = true) {
    $salary_period = get_post_meta($post_id, 'job_msf__Salary_Period__c', true);
    
    switch ($salary_period) {
        case 'Hour':
            if ($enable_translations) {
                $salary_period_str = __('per hour', YSD_MYSOLUTION_TEXT_DOMAIN);
            } else {
                $salary_period_str = 'per hour';
            }
            break;

        case 'Month':
            if ($enable_translations) {
                $salary_period_str = __('per month', YSD_MYSOLUTION_TEXT_DOMAIN);
            } else {
                $salary_period_str = 'per month';
            }            
            break;

        case 'Year':
            if ($enable_translations) {
                $salary_period_str = __('per year', YSD_MYSOLUTION_TEXT_DOMAIN);
            } else {
                $salary_period_str = 'per year';
            }               
            break;

        case 'Day':
            if ($enable_translations) {
                $salary_period_str = __('per day', YSD_MYSOLUTION_TEXT_DOMAIN);
            } else {
                $salary_period_str = 'per day';
            }            
            break;            
        
        default:
            $salary_period_str = '';
            break;
    }

    return $salary_period_str;
}

function ysd_mysolution_price_format($value = 0, $currency_symbol = '€', $decimal_separator = ',', $thousands_separator = '') {
    return $currency_symbol . ' ' . number_format($value, 2, $decimal_separator, $thousands_separator);
}

function ysd_mysolution_parttime_or_fulltime($hoursperweek) {
    if (empty($hoursperweek)) {
        return 'fulltime';
    }
    $hoursperweek = str_replace(
        array(
            ' ',
            'uur'
        ),
        '',
        $hoursperweek
    );
    $hoursperweek_arr = explode('-', $hoursperweek);
    if ((isset($hoursperweek_arr[0])) && ($hoursperweek_arr[0] < 30)) {
        $output = 'parttime';
    } else {
        $output = 'fulltime';
    }

    if ((isset($hoursperweek_arr[1])) && ($hoursperweek_arr[1] > 30)) {
        if ($output == 'parttime') {
            $output = 'parttime,fulltime';
        }
    }

    return $output;
}

function ysd_mysolution_decode_html_special_chars($input) {
    $output = htmlspecialchars_decode($input, ENT_QUOTES);
    $output = str_replace('&amp;', "&", $output);
    return $output;
}