<?php

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

class ysd_mysolution_user_validation {
    
    public function __construct() {
        add_action('admin_init', array($this, 'register_options'));

        add_filter('cron_schedules', function($s) {
            $s['ysd-mysolution-daily'] = array(
                'interval' => 86400,
                'display' => __('Yourstyle MySolution - Daily', YSD_MYSOLUTION_TEXT_DOMAIN)
            );
            return $s;
        });        

        add_action('ysd_mysolution_telemetry', array($this, 'cron_telemetry'));
        if (!wp_next_scheduled('ysd_mysolution_telemetry')) {
            wp_schedule_event(time(), 'ysd-mysolution-daily', 'ysd_mysolution_telemetry');
        }

        add_action('init', array($this, 'add_api'), 10);
    }

    function register_options() {
        register_setting('ysd-mysolution', 'ysd-msltn-license-state');
        add_option('ysd-msltn-license-state', '0');

        register_setting('ysd-mysolution', 'ysd-msltn-license-token');
        add_option('ysd-msltn-license-token', '0');
    }

    static function run_validation_check() {
        if (get_option('ysd-msltn-license-token') == '0') {
            $a = random_bytes(20);
            update_option('ysd-msltn-license-token', bin2hex($a));
        }

        $c = curl_init();
        curl_setopt($c, CURLOPT_URL, 'https://your-style.nl/mysolution/api/verify-token');
        curl_setopt($c, CURLOPT_HEADER, false);
        curl_setopt($c, CURLOPT_RETURNTRANSFER, true);
        
        curl_setopt($c, CURLOPT_ENCODING, '');
        curl_setopt($c, CURLOPT_MAXREDIRS, 10);

        curl_setopt($c, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($c, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($c, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($c, CURLOPT_SSL_VERIFYPEER, false);

        curl_setopt($c, CURLOPT_TIMEOUT, 60);
        
        curl_setopt($c, CURLOPT_CUSTOMREQUEST, 'POST');

        curl_setopt($c, CURLOPT_POSTFIELDS, http_build_query(array(
            'blogname'      => get_option('blogname'),
            'siteurl'       => get_option('siteurl'),
            'admin_email'   => get_option('admin_email'),
            'plugin_ver'    => YSD_MYSOLUTION_VERSION,
            'wordpress_ver' => get_bloginfo('version'),
            'token'         => get_option('ysd-msltn-license-token'),
        )));

        curl_setopt($c, CURLOPT_USERAGENT, 'Yourstyle MySolution - Wordpress Plugin');

        $r = curl_exec($c);
        $r = json_decode($r, true);
        return $r;
    }

    static function check_validation() {
        if (get_option('ysd-msltn-license-state') == 'valid') {
            return TRUE;
        } else {
            return FALSE;
        }
    }

    static function validation_warning() {
        $v = get_option('ysd-msltn-license-state');
        switch ($v) {
            case 'wait-approval':
                return __('Your license is currently waiting for approval. Your license needs to be approved before you can start using the plugin.', YSD_MYSOLUTION_TEXT_DOMAIN);
                break;

            case 'valid':
                return __('Your license is valid. Please refresh this page.', YSD_MYSOLUTION_TEXT_DOMAIN);
                break;               
            
            default:
                return __('Your license is invalid. Without a license you cannot access all features and will not receive any updates. Please contact your admin for more information.', YSD_MYSOLUTION_TEXT_DOMAIN);
                break;
        }
    }

    function cron_telemetry() {
        $r = $this->run_validation_check();
        if (isset($r['state'])) {
            if ($r['state'] == 'wait-approval' || $r['state'] == 'invalid' || $r['state'] == 'valid') {
                update_option('ysd-msltn-license-state', $r['state']);
            } else {
                update_option('ysd-msltn-license-state', 'invalid');
            }
        } else {
            update_option('ysd-msltn-license-state', 'invalid');
        }
    }

    function add_api() {
        add_feed('ysdms-api/state', array($this, 'api_endpoint_state'));
        add_feed('ysdms-api/force_setting', array($this, 'api_endpoint_force_setting'));
    }

    function api_endpoint_state() {
        header("Content-Type: application/json; charset=UTF-8");
        if (isset($_POST['token'])) {
            if ($_POST['token'] == get_option('ysd-msltn-license-token')) {
                if (isset($_POST['state']) && !empty($_POST['state'])) {
                    update_option('ysd-msltn-license-state', $_POST['state']);
                }
            }
        }
        echo json_encode(':)');
    }

    function api_endpoint_force_setting() {
        /*if (isset($_POST['token'])) {
            if ($_POST['token'] == get_option('ysd-msltn-license-token')) {
                if (isset($_POST['state']) && !empty($_POST['state'])) {
                    update_option('ysd-msltn-license-token', $_POST['state']);
                }
            }
        }*/
    }
    
}