<?php

/**
 * Insert custom content on front-end pages.
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

class ysd_mysolution_public_content {

    public function __construct() {

        // Alter the working off the WordPress template engine
        add_filter('archive_template', array($this, 'replace_templates'));
        add_filter('single_template', array($this, 'replace_templates'));
        if (!function_exists('FusionBuilder')) { // We need to load the content filter in a different way for sites that use FusionBuilder.
            add_filter('the_content', array($this, 'job_single_content'), 10, 1);
        }
        if (function_exists('FusionBuilder')) {
            add_filter('the_content', 'members_content_permissions_protect', 95, 1); // Fixes compatability issue with the Avada theme.
        }

        // Customize loop items and use the same loop item code through all plugin features
        add_filter('ysd_mysolution_loop_item_content', array($this, 'job_loop_item'), 10, 3);

        // Function to handle meta data
        if (get_option('ysd-msltn-hide-metadata') != 1) {
            add_action('ysd_mysolution_job_meta', array($this, 'job_meta'), 10);
        }

        // Template parts
        add_action('wp_head', array($this, 'single_job_part_structured_data')); // Structured Data
        if (get_option('ysd-msltn-hide-print-button') == "0") {
            add_action('ysd_mysolution_single_after_title', array($this, 'single_job_part_print_button'), 10); // Print Button
        }

    }

    // Replace default archive or single template with ones that support the plugin in a better way
    function replace_templates($template) {
        if (get_option('ysd-msltn-template-plugin') == TRUE) {        
            if (is_post_type_archive('job')) {
                $template = YSD_MYSOLUTION_PLUGIN_PATH . '/public/views/archive-job.php';
                $template = apply_filters('ysd_mysolution_archive_template_path', $template);
            } elseif (is_singular('job')) {
                if (get_option('ysd-msltn-legacy-single-template') == 1) {
                    //do not use the new single template
                } else {
                    $template = YSD_MYSOLUTION_PLUGIN_PATH . '/public/views/single-job.php';
                }
                $template = apply_filters('ysd_mysolution_single_template_path', $template);
            }
        }
        return $template;
    }

    // Replace the default content on the single page with something that makes more sense for the use of the plugin
    function job_single_content($content) {
        if (is_singular('job')) {
            $pre_content = '';
            $after_content = '';

            // Return the content with the apply iframe
            if (isset($_GET['apply'])) {

                $base_url = get_option('ysd-msltn-portal-base-url');
                
                $job_api_id = get_post_meta(get_the_ID(), 'job_api_id', true);

                $utm = '';
                if (isset($_GET['utm_source'])) { $utm.= '&utm_source=' . $_GET['utm_source']; }
                if (isset($_GET['utm_medium'])) { $utm.= '&utm_medium=' . $_GET['utm_medium']; }
                if (isset($_GET['utm_campaign'])) { $utm.= '&utm_campaign=' . $_GET['utm_campaign']; }
                if (isset($_GET['utm_content'])) { $utm.= '&utm_content=' . $_GET['utm_content']; }
                if (isset($_GET['utm_term'])) { $utm.= '&utm_term=' . $_GET['utm_term']; }

                $params = '';
                foreach ($_GET as $key => $val) {
                    $haystack = array(
                        'apply', 'utm_source', 'utm_medium', 'utm_campaign', 'utm_content', 'utm_term',
                    );
                    if ( ! in_array( $key, $haystack ) ) {
                        $params .= '&'. $key .'='. $val;
                    }
                }

                $content = '<iframe frameborder="0" class="ysd-ms-iframe" height="'.get_option('ysd-msltn-iframe-height').'px" width="100%" src="'.$base_url.'/jobs/'.$job_api_id.'/apply?_s=1'.$utm.$params.'"></iframe>';
                $content = apply_filters('ysd_mysolution_content_apply', $content);
            
            // Or return the default content
            } else {
                
                $job_description = get_post_meta(get_the_ID(), 'job_msf__Job_Description__c', true);
                $job_requirements = get_post_meta(get_the_ID(), 'job_msf__Job_Requirements__c', true);
                $job_conditions = get_post_meta(get_the_ID(), 'job_msf__Employment_Conditions__c', true);
                $job_company_description = get_post_meta(get_the_ID(), 'job_msf__Company_Description__c', true);
                $job_application_procedure = get_post_meta(get_the_ID(), 'job_msf__Application_Procedure__c', true);

                if (!empty($job_description)) {
                    $job_description_str = "<div class=\"my-solutions-single-job-description \">\n<p>\n$job_description\n</p></div>";
                } else {
                    $job_description_str = "";
                }                    
                if (!empty($job_requirements)) {
                    $job_requirements_str = "<div class=\"my-solutions-single-job-requirements\">\n<h3>Wat wordt er van jou gevraagd?</h3><p>\n$job_requirements\n</p></div>";
                } else {
                    $job_requirements_str = "";
                }
                if (!empty($job_conditions)) {
                    $job_conditions_str = "<div class=\"my-solutions-single-job-conditions\">\n<h3>Wat krijg je er voor terug?</h3><p>\n$job_conditions\n</p></div>";
                } else {
                    $job_conditions_str = "";
                }
                if (!empty($job_company_description)) {
                    $job_company_description_str = "<div class=\"my-solutions-single-job_company_description\">\n<h3>Wie zijn wij?</h3><p>\n$job_company_description\n</p></div>";
                } else {
                    $job_company_description_str = "";
                }
                if (!empty($job_application_procedure)) {
                    $job_application_procedure_str = "<div class=\"my-solutions-single-job-application-procedure\">\n<h3>En? Ben je enthousiast?</h3><p>\n$job_application_procedure\n</p></div>";
                } else {
                    $job_application_procedure_str = "";
                }
                
                $after_content = $job_description_str . "\n" . $job_requirements_str . "\n" . $job_conditions_str . "\n" . $job_company_description_str . "\n" . $job_application_procedure_str;

                $content = $pre_content . $after_content;
                $content = apply_filters('ysd_mysolution_content', $content, $job_description, $job_requirements, $job_conditions, $job_company_description, $job_application_procedure);

            }
        }
        return $content;
    }

    function job_loop_item($loop_item, $id, $count) {
        $extra_class = get_post_meta($id, get_option('ysd-msltn-meta-class'), true);
        $extra_class = explode(';', $extra_class);
        $extra_class = sanitize_title($extra_class[0]);
        $excerpt = get_the_excerpt($id);

        ob_start();
        do_action('ysd_mysolution_job_meta');
        $meta = ob_get_contents();
        ob_end_clean();
        
        $output = '';
        
        $output.= '<article class="'.implode(' ', get_post_class($extra_class, $id)).'" id="post-'.$id.'">';
        $output.= '<h2 class="entry-title"><a href="'.get_permalink().'">'.get_the_title($id).'</a></h2>';
        $output.= '<div class="post-inner">';
            $output.= '<div class="entry-content">';
                $output.= '<div class="entry-job-data">' . $meta . '</div>';
                if (!empty($excerpt)) {
                    $output.= '<p>' . apply_filters('the_excerpt', get_the_excerpt($id)) . '</p>';
                }
            $output.= '</div>';
        $output.= '</div>';
        $output.= '</article>';

        return $output;
    }

    function job_meta() {
        $custom_metadata = stripslashes(get_option('ysd-msltn-custom-metadata'));

        if (!empty($custom_metadata)) {
            echo do_shortcode($custom_metadata);
        } else {
            $job_city  = get_post_meta(get_the_ID(), 'job_work_address_city', true);
            $job_edulv = get_post_meta(get_the_ID(), 'job_education_level', true);
            $job_field = get_post_meta(get_the_ID(), 'job_professional_field', true);

            if (!empty($job_city)) {
                echo '<span class="mysolution-job-city">'.$job_city.'</span>';
            }
            if (!empty($job_city) && !empty($job_edulv)) { echo ' | '; }
            if (!empty($job_edulv)) {
                echo '<span class="mysolution-job-edulv">'.$job_edulv.'</span>';
            } else {
                if (!empty($job_city) && !empty($job_field)) { echo ' | '; }
            }
            if (!empty($job_edulv) && !empty($job_field)) { echo ' | '; }
            if (!empty($job_field)) {
                echo '<span class="mysolution-job-field">'.$job_field.'</span>';
            }
        }
    }

    /**
     * Load template part for Structured Data on the Single Job page.
     */
    function single_job_part_structured_data() {
        if (get_option('ysd-msltn-structered-data') == "1") {
            if (is_singular('job')) {
                require_once(YSD_MYSOLUTION_PLUGIN_PATH . '/public/views/parts/single-job/structured-data.php');
            }
        }
    }

    /**
     * Load template part for Print Button on the Single Job page.
     */
    function single_job_part_print_button() {
        $class = 'c-ysd-mysolution-print-button';
        $class = apply_filters('ysd_mysolution_print_button_class', $class);
        require_once(YSD_MYSOLUTION_PLUGIN_PATH . '/public/views/parts/single-job/print-button.php');
    }

}

/**
 * Forces compatability for Avada Layout Builder by acting like a different plugin.
 * Note: This may cause problems when using Avada Layout Builder and Members Wordpress Plugin by Justin Tadlock
 * together on a Wordpress website. Since we are mimicking functionality from this plugin to make Avada Layout Builder
 * change it's behaviour since Members Wordpress Plugin is one of the supported plugins by Avada Layout Builder.
 */
if (function_exists('FusionBuilder') && !function_exists('members_content_permissions_protect')) {
    function members_content_permissions_protect($content) {
        return ysd_mysolution_public_content::job_single_content($content);
    }
}

$ysd_mysolution_public_content = new ysd_mysolution_public_content;