<?php

/**
 * Legacy features that are no longer developed and will be removed in a later version of the plugin.
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

class ysd_mysolution_public_legacy {

	/**
	 * The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct($plugin_name, $version) {
		$this->plugin_name = $plugin_name;
        $this->version = $version;

        // Specific extra's for WPS Prime
        if (get_option('template') == 'wps-prime') {
            
            // Job slider
            require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/legacy/shortcode-latest-job-slider.php';
            new ysd_mysolution_public_shortcode_latest_job_slider;

            // Alter content for single job
            add_filter('ysd_mysolution_content', array($this, 'filter_content_wps_prime'), 10, 6);

            // Load scripts for use on the front-end
            add_action('wp_enqueue_scripts', array($this, 'plugin_scripts_wps_prime'));

            // Replace default templates with ones that support the plugin in a better way
            add_filter('ysd_mysolution_archive_template_path', array($this, 'custom_template_archive_wps_prime'));
        }

        // Specific extra's for Bridge
        if (function_exists('bridge_qode_styles')) {
            
            // Replace default templates with ones that support the plugin in a better way
            add_filter('single_template', array($this, 'custom_template_single_bridge'));
            add_filter('ysd_mysolution_archive_template_path', array($this, 'custom_template_archive_bridge'));

        }

        // Legacy hooks
        add_action('ysd_mysolution_archive_before_content', function(){ do_action('ysd-mysolution-archive-before-content'); }, 1, 1);
        add_action('ysd_mysolution_archive_after_content', function(){ do_action('ysd-mysolution-archive-after-content'); }, 1, 1);
    }

    function plugin_scripts_wps_prime() {
        if (get_option('template') == 'wps-prime') {
            wp_register_script('wps-slider', YSD_MYSOLUTION_PLUGIN_URL . '/assets/js/wps-slider.js', array('slider_core'), '1.0', true);
        }
    }

    function filter_content_wps_prime($content, $job_description, $job_requirements, $job_conditions, $job_company_description, $job_application_procedure) {
        if (!empty($job_description)) {
            $job_description_str = "<div class=\"my-solutions-single-job-description \">\n<p>\n$job_description\n</p></div>";
        } else {
            $job_description_str = "";
        }
        if (!empty($job_requirements)) {
            $job_requirements_str = "<div class=\"my-solutions-single-job-requirements u-background-light \">\n<h4>Wat wordt er van jou gevraagd?</h4><p>\n$job_requirements\n</p></div>";
        } else {
            $job_requirements_str = "";
        }
        if (!empty($job_conditions)) {
            $job_conditions_str = "<div class=\"my-solutions-single-job-conditions\">\n<h4>Wat krijg je er voor terug?</h4><p>\n$job_conditions\n</p></div>";
        } else {
            $job_conditions_str = "";
        }
        if (!empty($job_company_description)) {
            $job_company_description_str = "<div class=\"my-solutions-single-job_company_description\">\n<h4>Wie zijn wij?</h4><p>\n$job_company_description\n</p></div>";
        } else {
            $job_company_description_str = "";
        }
        if (!empty($job_application_procedure)) {
            $job_application_procedure_str = "<div class=\"my-solutions-single-job-application-procedure\">\n<h4>En? Ben je enthousiast?</h4><p>\n$job_application_procedure\n</p></div>";
        } else {
            $job_application_procedure_str = "";
        }

        return $job_description_str . "\n" . $job_requirements_str . "\n" . $job_conditions_str . "\n" . $job_company_description_str . "\n" . $job_application_procedure_str;
    }

    function custom_template_single_bridge($template) {
        if (get_option('ysd-msltn-template-plugin') == TRUE) {
            if (is_singular('job')) {
                $template = YSD_MYSOLUTION_PLUGIN_PATH . '/public/legacy/views/bridge/single-job.php';
            }
        }
        return $template;
    }

    function custom_template_archive_bridge($template) {
        return YSD_MYSOLUTION_PLUGIN_PATH . '/public/legacy/views/bridge/archive-job.php';
    }

    function custom_template_archive_wps_prime($template) {
        return YSD_MYSOLUTION_PLUGIN_PATH . '/public/legacy/views/wps-prime/archive-job.php';
    }

}