<?php

/**
 * The front-end functionality of the plugin.
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

class ysd_mysolution_public {

	/**
	 * The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct($plugin_name, $version) {
		$this->plugin_name = $plugin_name;
        $this->version = $version;

        // Load scripts for use on the front-end
        add_action('wp_enqueue_scripts', array($this, 'plugin_scripts'));

        // Content related functions
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/content.php';

        // Register plugin shortcodes
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_jobs.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_jobs_legacy.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_job_link.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_job_link_apply.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_job_taxonomy.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_job_field.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/shortcodes/shortcode_count_jobs.php';

        // Register XML feeds
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/feeds/feeds.php';

        // Register widget area for archive template
        add_action('init', array($this, 'register_widget_area'), 10);

        // Alter query on Job Archives
        add_action('pre_get_posts', array($this, 'alter_job_archive_query'), 10);
    }

    // Load scripts for use on the front-end
    function plugin_scripts() {
        wp_enqueue_style('ysd_mysolution_style', YSD_MYSOLUTION_PLUGIN_URL . '/assets/css/style.css', false); //Regular styling
    }

    function register_widget_area() {
        if (get_option('ysd-msltn-jobs-add-archive-sidebar') == "1") {
            if (function_exists('register_sidebar')) {
                register_sidebar(array(
                    'name'				=> __('MySolution Sidebar: Archive Page', YSD_MYSOLUTION_TEXT_DOMAIN),
                    'id'				=> 'ysdms-sidebar-widgets',
                    'before_widget'		=> '<div id="%1$s" class="%2$s widget">',
                    'after_widget'		=> '</div>',
                    'before_title'		=> '<h3 class="title">',
                    'after_title'		=> '</h3>',
                ));            
            }
        }
        if (get_option('ysd-msltn-jobs-add-single-sidebar') == "1") {
            if (function_exists('register_sidebar')) {
                register_sidebar(array(
                    'name'				=> __('MySolution Sidebar: Single Page', YSD_MYSOLUTION_TEXT_DOMAIN),
                    'id'				=> 'ysdms-sidebar-widgets-single',
                    'before_widget'		=> '<div id="%1$s" class="%2$s widget">',
                    'after_widget'		=> '</div>',
                    'before_title'		=> '<h3 class="title">',
                    'after_title'		=> '</h3>',
                ));            
            }
        }        
    }

    // Alter job query on archive pages
    function alter_job_archive_query($query) {
        if (is_admin() || ! $query->is_main_query()) {
            return;
        }

        if ($query->is_archive()) {
            $args = array();

            $numberposts = get_option('ysd-msltn-archive-jobs-per-page');
            if (!empty($numberposts)) {
                $query->set('posts_per_page', $numberposts);
            }
        }
    }

}