<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package WordPress
 * @subpackage Twenty_Twenty
 * @since Twenty Twenty 1.0
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

get_header();
?>

<main id="site-content" role="main">

        <div class="ysdms-main-wrap">
        
        <?php do_action('ysd_mysolution_archive_before_content'); ?>

        <?php if (get_option('ysd-msltn-jobs-add-archive-sidebar') == "1") : ?>
        <div class="ysdms-sidebar">
            <?php
                do_action('ysd_mysolution_archive_prepend_sidebar');
                dynamic_sidebar('ysdms-sidebar-widgets');
                do_action('ysd_mysolution_archive_append_sidebar');
            ?>
        </div>
        <?php endif; ?>

        <div class="ysdms-main">

            <?php do_action('ysd_mysolution_archive_prepend_content'); ?>

            <header class="archive-header has-text-align-center header-footer-group">

                <div class="archive-header-inner section-inner medium">

                    <?php do_action('ysd_mysolution_archive_before_title'); ?>
                    <h1 class="archive-title"><?php _e('Jobs', YSD_MYSOLUTION_TEXT_DOMAIN); ?></h1>
                    <?php do_action('ysd_mysolution_archive_after_title'); ?>

                </div><!-- .archive-header-inner -->

            </header><!-- .archive-header -->

            <?php

            if ( have_posts() ) {

                $i = 0;

                while ( have_posts() ) {
                    $i++;
                    the_post();

                    $loop_item = '';
                    echo apply_filters('ysd_mysolution_loop_item_content', $loop_item, get_the_ID(), $i);

                }
            }
            ?>

            <?php do_action('ysd_mysolution_archive_append_content'); ?>

        </div>

        <?php do_action('ysd_mysolution_archive_after_content'); ?>
        
        </div>

    <?php

    $prev_text = sprintf(
        '%s <span class="nav-prev-text">%s</span>',
        '<span aria-hidden="true">&larr;</span>',
        __( 'Newer <span class="nav-short">Posts</span>', YSD_MYSOLUTION_TEXT_DOMAIN )
    );
    $next_text = sprintf(
        '<span class="nav-next-text">%s</span> %s',
        __( 'Older <span class="nav-short">Posts</span>', YSD_MYSOLUTION_TEXT_DOMAIN ),
        '<span aria-hidden="true">&rarr;</span>'
    );

    $posts_pagination = get_the_posts_pagination(
        array(
            'mid_size'  => 1,
            'prev_text' => $prev_text,
            'next_text' => $next_text,
        )
    );

    // If we're not outputting the previous page link, prepend a placeholder with `visibility: hidden` to take its place.
    if ( strpos( $posts_pagination, 'prev page-numbers' ) === false ) {
        $posts_pagination = str_replace( '<div class="nav-links">', '<div class="nav-links"><span class="prev page-numbers placeholder" aria-hidden="true">' . $prev_text . '</span>', $posts_pagination );
    }

    // If we're not outputting the next page link, append a placeholder with `visibility: hidden` to take its place.
    if ( strpos( $posts_pagination, 'next page-numbers' ) === false ) {
        $posts_pagination = str_replace( '</div>', '<span class="next page-numbers placeholder" aria-hidden="true">' . $next_text . '</span></div>', $posts_pagination );
    }

    if ( $posts_pagination ) { ?>

        <div class="pagination-wrapper section-inner">

            <hr class="styled-separator pagination-separator is-style-wide" aria-hidden="true" />

            <?php echo $posts_pagination; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- already escaped during generation. ?>

        </div><!-- .pagination-wrapper -->

        <?php
    }

    ?>

</main><!-- #site-content -->

<?php
get_footer();
