<?php

/**
 * Plugin Name:       Yourstyle - Mysolution
 * Plugin URI:        https://your-style.nl
 * Description:       Retrieves Jobs from Mysolution for display on your website. Working API credentials are needed to make this plugin work, see Jobs > Settings.
 * Version:           1.11.5
 * Author:            Yourstyle
 * Author URI:        https://your-style.nl
 * License:           GPL 2.0
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       ysd-mysolution
 * Domain Path:       /languages
 * Requires at least: 5.5.0
 * Requires PHP:      7.4.0 or later
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
	die;
}

define('YSD_MYSOLUTION_VERSION', '1.11.5');
define('YSD_MYSOLUTION_DBREVISION', '6');
define('YSD_MYSOLUTION_PLUGIN_NAME', 'ysd-mysolution');
define('YSD_MYSOLUTION_TEXT_DOMAIN', 'ysd-mysolution');
define('YSD_MYSOLUTION_PLUGIN_BASE_FILE', plugin_basename(__FILE__));
define('YSD_MYSOLUTION_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('YSD_MYSOLUTION_PLUGIN_URL', plugins_url('', __FILE__));
define('YSD_MYSOLUTION_PLUGIN_NICE_NAME', __('Yourstyle - Mysolution', YSD_MYSOLUTION_TEXT_DOMAIN));
define('YSD_MYSOLUTION_PLUGIN_DESCRIPTION', __('Retrieves Jobs from Mysolution for display on your website. Working API credentials are needed to make this plugin work, see Jobs > Settings.', YSD_MYSOLUTION_TEXT_DOMAIN));
define('YSD_MYSOLUTION_PLUGIN_AUTHOR', __('Yourstyle', YSD_MYSOLUTION_TEXT_DOMAIN));
define('YSD_MYSOLUTION_PLUGIN_AUTHOR_URI', __('https://your-style.nl', YSD_MYSOLUTION_TEXT_DOMAIN));

require_once(YSD_MYSOLUTION_PLUGIN_PATH . 'includes/helper-functions.php');
require_once(YSD_MYSOLUTION_PLUGIN_PATH . 'includes/helper-shortcodes.php');
require_once(YSD_MYSOLUTION_PLUGIN_PATH . 'includes/default-fields.php');

require_once(YSD_MYSOLUTION_PLUGIN_PATH . 'includes/bwhf/bwhf.php');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-ysd-refurbed-api-connector-activator.php
 */
function ysd_mysolution_activate() {
	ysd_mysolution::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-ysd-refurbed-api-connector-deactivator.php
 */
function ysd_mysolution_deactivate() {
	ysd_mysolution::deactivate();
}

register_activation_hook(__FILE__, 'ysd_mysolution_activate');
register_deactivation_hook(__FILE__, 'ysd_mysolution_deactivate');

/**
 * Main plugin class that handles all the general stuff.
 */
class ysd_mysolution {

	/**
	 * The unique identifier of this plugin.
	 */
    protected $plugin_name;

	/**
	 * The display name of this plugin.
	 */
    protected $plugin_nice_name;
    
	/**
	 * The current version of the plugin.
	 */
    protected $version;
    

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 */
	public function __construct() {

		if (defined('YSD_MYSOLUTION_VERSION')) {
			$this->version = YSD_MYSOLUTION_VERSION;
		} else {
			$this->version = '1.0.0';
        }
		if (defined('YSD_MYSOLUTION_PLUGIN_NAME')) {
			$this->plugin_name = YSD_MYSOLUTION_PLUGIN_NAME;
		} else {
			$this->plugin_name = 'plugin';
        }
		if (defined('YSD_MYSOLUTION_PLUGIN_NICE_NAME')) {
			$this->plugin_name = YSD_MYSOLUTION_PLUGIN_NICE_NAME;
		} else {
			$this->plugin_name = 'Plugin';
		}

        /* Add support for translations */
        load_plugin_textdomain(YSD_MYSOLUTION_TEXT_DOMAIN, false, dirname(plugin_basename(__FILE__)) . '/languages/');

        $this->load_dependencies();
		$this->define_admin_hooks();
        $this->define_public_hooks();
        
    }
    
	/**
	 * Load the required dependencies for this plugin.
	 */
    private function load_dependencies() {

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/admin/admin.php';

		/**
		 * The class responsible for defining all actions that occur on the front-end.
		 */
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/public.php';
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/public/public-legacy.php';


        /* The API Class */
        require_once YSD_MYSOLUTION_PLUGIN_PATH . '/includes/api-mysolution.php';

    }
    
    /**
     * Fired during plugin activation.
     *
     * This class defines all code necessary to run during the plugin's activation.
     */
    public static function activate() {}
    
    /**
     * Fired during plugin deactivation.
     *
     * This class defines all code necessary to run during the plugin's deactivation.
     */
    public static function deactivate() {}

	/**
	 * Register all of the hooks related to the admin area functionality of the plugin.
	 */
	private function define_admin_hooks() {

		$plugin_admin = new ysd_mysolution_admin($this->get_plugin_name(), $this->get_version());

    }
    
	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 */
	private function define_public_hooks() {

		$plugin_public = new ysd_mysolution_public($this->get_plugin_name(), $this->get_version());
        $plugin_public_legacy = new ysd_mysolution_public_legacy($this->get_plugin_name(), $this->get_version());

	}
    
	/**
	 * The name of the plugin used to uniquely identify it within the context of WordPress and to define internationalization functionality.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
    }

	/**
	 * Retrieve the display name of the plugin.
	 */
	public function get_plugin_display_name() {
		return $this->plugin_nice_name;
	}
    
	/**
	 * Retrieve the version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
    }

}

require_once(YSD_MYSOLUTION_PLUGIN_PATH . 'includes/user-validation.php');

/**
 * Run the plugin.
 */
$ysd_mysolution = new ysd_mysolution();